@@ -14,34 +14,27 @@
         ")",
         collapse = " + "
       )
-      return(
-        paste0(
-          "eta_",
-          i,
-          " ~ ",
-          terms
-        )
+      paste0(
+        "eta_",
+        i,
+        " ~ ",
+        terms
       )
     }
   )
   if (intercept) {
-    return(
-      lapply(
-        X = seq_len(length(formula)),
-        FUN = function(i) {
-          paste0(
-            formula[[i]],
-            " + ",
-            "alpha_",
-            i,
-            "_1"
-          )
-        }
-      )
-    )
-  } else {
-    return(
-      formula
+    formula <- lapply(
+      X = seq_len(length(formula)),
+      FUN = function(i) {
+        paste0(
+          formula[[i]],
+          " + ",
+          "alpha_",
+          i,
+          "_1"
+        )
+      }
     )
   }
+  formula
 }
